@@ -4,6 +4,7 @@ from ..loader import HANDLERS
 
 
 def my_chat_member(
+        status: str | list[str] = None,
         user_id: int | list[int] = None,
         chat_type: str | list[str] = None,
         state: str = None,
@@ -13,6 +14,9 @@ def my_chat_member(
         filters.State(state),
     ]
 
+    if status:
+        _filters.append(filters.ChanMemberStatus(status))
+
     if user_id:
         _filters.append(filters.UserId(user_id))
 
